@@ -2,13 +2,15 @@ from taggit.managers import TaggableManager
 
 from nautobot.extras.models.change_logging import ChangeLoggedModel
 from nautobot.extras.models.customfields import CustomFieldModel
-from nautobot.extras.models.mixins import DynamicGroupMixin
+from nautobot.extras.models.mixins import DynamicGroupMixin, NotesMixin
 from nautobot.extras.models.relationships import RelationshipModel
 from nautobot.extras.models.tags import TaggedItem
 from nautobot.core.models import BaseModel
 
 
-class OrganizationalModel(BaseModel, ChangeLoggedModel, CustomFieldModel, RelationshipModel, DynamicGroupMixin):
+class OrganizationalModel(
+    BaseModel, ChangeLoggedModel, CustomFieldModel, RelationshipModel, DynamicGroupMixin, NotesMixin
+):
     """
     Base abstract model for all organizational models.
 
@@ -23,7 +25,7 @@ class OrganizationalModel(BaseModel, ChangeLoggedModel, CustomFieldModel, Relati
         abstract = True
 
 
-class PrimaryModel(BaseModel, ChangeLoggedModel, CustomFieldModel, RelationshipModel, DynamicGroupMixin):
+class PrimaryModel(BaseModel, ChangeLoggedModel, CustomFieldModel, RelationshipModel, DynamicGroupMixin, NotesMixin):
     """
     Base abstract model for all primary models.
 
