@@ -717,7 +717,7 @@ class GraphQLQueryTest(TestCase):
             RearPort.objects.create(device=cls.device1, name="Rear Port 1", type=PortTypeChoices.TYPE_8P8C),
             RearPort.objects.create(device=cls.device1, name="Rear Port 2", type=PortTypeChoices.TYPE_8P8C),
             RearPort.objects.create(device=cls.device1, name="Rear Port 3", type=PortTypeChoices.TYPE_8P8C),
-            RearPort.objects.create(device=cls.device1, name="Rear Port 4", type=PortTypeChoices.TYPE_8P8C),
+            RearPort.objects.create(device=cls.device1, name="Rear Port 4", type=PortTypeChoices.TYPE_8P4C),
         )
 
         cls.device1_console_ports = (
@@ -765,7 +765,7 @@ class GraphQLQueryTest(TestCase):
             FrontPort.objects.create(
                 device=cls.device1,
                 name="Front Port 4",
-                type=PortTypeChoices.TYPE_8P8C,
+                type=PortTypeChoices.TYPE_8P4C,
                 rear_port=cls.device1_rear_ports[3],
             ),
         ]
@@ -1006,21 +1006,23 @@ query {
     @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
     def test_query_config_context_and_custom_field_data(self):
 
-        query = """
-        query {
-            devices {
-                name
-                config_context
-                _custom_field_data
-            }
-            device (id: "%s") {
-                name
-                config_context
-                _custom_field_data
-            }
-        }
-        """ % (
-            self.device1.id,
+        query = (
+            # pylint: disable=consider-using-f-string
+            """
+                query {
+                    devices {
+                        name
+                        config_context
+                        _custom_field_data
+                    }
+                    device (id: "%s") {
+                        name
+                        config_context
+                        _custom_field_data
+                    }
+                }
+            """
+            % (self.device1.id)
         )
 
         expected_data = {"a": 123, "b": 456, "c": 777}
@@ -1168,20 +1170,23 @@ query {
         """Test queries involving relationship associations."""
 
         # Query testing for https://github.com/nautobot/nautobot/issues/1228
-        query = """
-        query {
-            device (id: "%s") {
-                name
-                rel_device_to_vm {
-                    id
+
+        query = (
+            # pylint: disable=consider-using-f-string
+            """
+                query {
+                    device (id: "%s") {
+                        name
+                        rel_device_to_vm {
+                            id
+                        }
+                        rel_device_group {
+                            id
+                        }
+                    }
                 }
-                rel_device_group {
-                    id
-                }
-            }
-        }
-        """ % (
-            self.device1.id,
+            """
+            % (self.device1.id)
         )
         result = self.execute_query(query)
 
@@ -1252,9 +1257,9 @@ query {
             ('status: ["status1", "status2"]', 2),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { sites(" + filter + "){ name }}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { sites(" + filterv + "){ name }}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["sites"]), nbr_expected_results)
@@ -1299,9 +1304,9 @@ query {
             ('q: "notthere"', 0),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query {devices(" + filter + "){ name }}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query {devices(" + filterv + "){ name }}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["devices"]), nbr_expected_results)
@@ -1323,9 +1328,9 @@ query {
             ('parent: "10.0.2.0/24"', 1),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { ip_addresses(" + filter + "){ address }}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { ip_addresses(" + filterv + "){ address }}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["ip_addresses"]), nbr_expected_results)
@@ -1395,9 +1400,9 @@ query {
             ('tenant: ["tenant-1", "tenant-2"]', 4),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { cables(" + filter + "){ id }}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { cables(" + filterv + "){ id }}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["cables"]), nbr_expected_results)
@@ -1409,12 +1414,12 @@ query {
         filters = (
             (f'name: "{self.device1_frontports[0].name}"', 1),
             (f'device: "{self.device1.name}"', 4),
-            (f'_type: "{PortTypeChoices.TYPE_8P8C}"', 4),
+            (f'_type: "{PortTypeChoices.TYPE_8P8C}"', 3),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { devices{ frontports(" + filter + "){ id }}}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { devices{ frontports(" + filterv + "){ id }}}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["devices"][0]["frontports"]), nbr_expected_results)
@@ -1426,12 +1431,12 @@ query {
         filters = (
             (f'name: "{self.device1_frontports[0].name}"', 1),
             (f'device: "{self.device1.name}"', 4),
-            (f'_type: "{PortTypeChoices.TYPE_8P8C}"', 4),
+            (f'_type: "{PortTypeChoices.TYPE_8P8C}"', 3),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { sites{ devices{ frontports(" + filter + "){ id }}}}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { sites{ devices{ frontports(" + filterv + "){ id }}}}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["sites"][0]["devices"][0]["frontports"]), nbr_expected_results)
@@ -1540,9 +1545,9 @@ query {
             ("enabled: false", 1),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { interfaces(" + filter + "){ id }}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { interfaces(" + filterv + "){ id }}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["interfaces"]), nbr_expected_results)
@@ -1559,9 +1564,9 @@ query {
             (f'vlan_id: "{self.vlan1.id}"', 1),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { devices{ interfaces(" + filter + "){ id }}}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { devices{ interfaces(" + filterv + "){ id }}}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["devices"][0]["interfaces"]), nbr_expected_results)
@@ -1578,9 +1583,9 @@ query {
             (f'vlan_id: "{self.vlan1.id}"', 1),
         )
 
-        for filter, nbr_expected_results in filters:
-            with self.subTest(msg=f"Checking {filter}", filter=filter, nbr_expected_results=nbr_expected_results):
-                query = "query { sites{ devices{ interfaces(" + filter + "){ id }}}}"
+        for filterv, nbr_expected_results in filters:
+            with self.subTest(msg=f"Checking {filterv}", filterv=filterv, nbr_expected_results=nbr_expected_results):
+                query = "query { sites{ devices{ interfaces(" + filterv + "){ id }}}}"
                 result = self.execute_query(query)
                 self.assertIsNone(result.errors)
                 self.assertEqual(len(result.data["sites"][0]["devices"][0]["interfaces"]), nbr_expected_results)
