@@ -2,7 +2,7 @@ import logging
 
 from cacheops import invalidate_obj
 from django.contrib.contenttypes.models import ContentType
-from django.db.models.signals import post_save, post_delete, pre_delete
+from django.db.models.signals import post_save, pre_delete
 from django.db import transaction
 from django.dispatch import receiver
 
@@ -50,37 +50,118 @@ def rebuild_paths(obj):
 
 
 #
-# Site/rack/device assignment
+# Site/location/rack/device assignment
 #
 
 
 @receiver(post_save, sender=RackGroup)
-def handle_rackgroup_site_change(instance, created, **kwargs):
+def handle_rackgroup_site_location_change(instance, created, **kwargs):
     """
-    Update child RackGroups and Racks if Site assignment has changed. We intentionally recurse through each child
-    object instead of calling update() on the QuerySet to ensure the proper change records get created for each.
+    Update child RackGroups, Racks, and PowerPanels if Site or Location assignment has changed.
+
+    We intentionally recurse through each child object instead of calling update() on the QuerySet
+    to ensure the proper change records get created for each.
+
+    Note that this is non-trivial for Location changes, since a LocationType that can contain RackGroups
+    may or may not be permitted to contain Racks or PowerPanels. If it's not permitted, rather than trying to search
+    through child locations to find the "right" one, the best we can do is simply to null out the location.
     """
     if not created:
+        if instance.location is not None:
+            descendants = instance.location.descendants(include_self=True)
+            content_types = instance.location.location_type.content_types.all()
+            rack_groups_permitted = ContentType.objects.get_for_model(RackGroup) in content_types
+            racks_permitted = ContentType.objects.get_for_model(Rack) in content_types
+            power_panels_permitted = ContentType.objects.get_for_model(PowerPanel) in content_types
+        else:
+            descendants = None
+            rack_groups_permitted = False
+            racks_permitted = False
+            power_panels_permitted = False
+
         for rackgroup in instance.get_children():
-            rackgroup.site = instance.site
-            rackgroup.save()
-        for rack in Rack.objects.filter(group=instance).exclude(site=instance.site):
-            rack.site = instance.site
-            rack.save()
-        for powerpanel in PowerPanel.objects.filter(rack_group=instance).exclude(site=instance.site):
-            powerpanel.site = instance.site
-            powerpanel.save()
+            changed = False
+            if rackgroup.site != instance.site:
+                rackgroup.site = instance.site
+                changed = True
+
+            if instance.location is not None:
+                if rackgroup.location is not None and rackgroup.location not in descendants:
+                    rackgroup.location = instance.location if rack_groups_permitted else None
+                    changed = True
+            elif rackgroup.location is not None and rackgroup.location.base_site != instance.site:
+                rackgroup.location = None
+                changed = True
+
+            if changed:
+                rackgroup.save()
+
+        for rack in Rack.objects.filter(group=instance):
+            changed = False
+            if rack.site != instance.site:
+                rack.site = instance.site
+                changed = True
+
+            if instance.location is not None:
+                if rack.location is not None and rack.location not in descendants:
+                    rack.location = instance.location if racks_permitted else None
+                    changed = True
+            elif rack.location is not None and rack.location.base_site != instance.site:
+                rack.location = None
+                changed = True
+
+            if changed:
+                rack.save()
+
+        for powerpanel in PowerPanel.objects.filter(rack_group=instance):
+            changed = False
+            if powerpanel.site != instance.site:
+                powerpanel.site = instance.site
+                changed = True
+
+            if instance.location is not None:
+                if powerpanel.location is not None and powerpanel.location not in descendants:
+                    powerpanel.location = instance.location if power_panels_permitted else None
+                    changed = True
+            elif powerpanel.location is not None and powerpanel.location.base_site != instance.site:
+                powerpanel.location = None
+                changed = True
+
+            if changed:
+                powerpanel.save()
 
 
 @receiver(post_save, sender=Rack)
-def handle_rack_site_change(instance, created, **kwargs):
+def handle_rack_site_location_change(instance, created, **kwargs):
     """
-    Update child Devices if Site assignment has changed.
+    Update child Devices if Site or Location assignment has changed.
+
+    Note that this is non-trivial for Location changes, since a LocationType that can contain Racks
+    may or may not be permitted to contain Devices. If it's not permitted, rather than trying to search
+    through child locations to find the "right" one, the best we can do is simply to null out the location.
     """
     if not created:
-        for device in Device.objects.filter(rack=instance).exclude(site=instance.site):
-            device.site = instance.site
-            device.save()
+        if instance.location is not None:
+            devices_permitted = (
+                ContentType.objects.get_for_model(Device) in instance.location.location_type.content_types.all()
+            )
+
+        for device in Device.objects.filter(rack=instance):
+            changed = False
+            if device.site != instance.site:
+                device.site = instance.site
+                changed = True
+
+            if instance.location is not None:
+                if device.location is not None and device.location != instance.location:
+                    device.location = instance.location if devices_permitted else None
+                    changed = True
+            elif device.location is not None and device.location.base_site != instance.site:
+                device.location = None
+                changed = True
+
+            if changed:
+                device.save()
 
 
 #
@@ -157,7 +238,7 @@ def update_connected_endpoints(instance, created, raw=False, **kwargs):
             rebuild_paths(instance)
 
 
-@receiver(post_delete, sender=Cable)
+@receiver(pre_delete, sender=Cable)
 def nullify_connected_endpoints(instance, **kwargs):
     """
     When a Cable is deleted, check for and update its two connected endpoints
